==> spip_3.0.21.orig.tar.xz: spip/ecrire/lang/public_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuèlh',
	'article' => 'Article',
	'articles' => 'Article',
	'articles_auteur' => 'Article d’aquel autour',
	'articles_populaires' => 'Lu article lu mai poupulari',
	'articles_rubrique' => 'Article d’aquela rùbrica',
	'aucun_article' => 'Lì es mìnga d’article en aquela adressa',
	'aucun_auteur' => 'Lì es mìnga d’autour en aquela adressa',
	'aucun_site' => 'Lì es mìnga de sit en aquela adressa',
	'aucune_breve' => 'Lì es mìnga de brèva en aquela adressa',
	'aucune_rubrique' => 'Lì es mìnga de rùbrica en aquela adressa',
	'auteur' => 'Autour',
	'autres' => 'Autre',
	'autres_breves' => 'Autri brèva',
	'autres_groupes_mots_clefs' => 'Autre groupe de mot clau',
	'autres_sites' => 'Autre sit',

	// B
	'bonjour' => 'Bouònjou',

	// C
	'commenter_site' => 'Coumentà aqueu sit',
	'contact' => 'Countat',
	'copie_document_impossible' => 'Empoussible de coupià lou doucumen',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrié ajust',
	'dernieres_breves' => 'Darrieri brèva',
	'derniers_articles' => 'Darrié article',
	'derniers_commentaires' => 'Darrié coumentari',
	'derniers_messages_forum' => 'Darrié message publicat en lu fòrou',

	// E
	'edition_mode_texte' => 'Edicioun en mòdou tèst de',
	'en_reponse' => 'En respouòsta a :',
	'en_resume' => 'En coumpendiat',
	'envoyer_message' => 'Mandà un message',
	'espace_prive' => 'Espaci privat',

	// F
	'formats_acceptes' => 'Fourmat achetat : @formats@.',

	// H
	'hierarchie_site' => 'Ierarquìa dóu sit',

	// J
	'jours' => 'jou',

	// L
	'lien_connecter' => 'Si counetà',

	// M
	'meme_auteur' => 'Dóu meme autour',
	'meme_rubrique' => 'En la mema rùbrica',
	'memes_auteurs' => 'Dei meme autour',
	'message' => 'Message',
	'messages_forum' => 'Message',
	'messages_recents' => 'Lu message de fòrou lu mai rechent',
	'mots_clef' => 'Mot clau',
	'mots_clefs' => 'Mot clau',
	'mots_clefs_meme_groupe' => 'Mot clau en lou meme groupe',

	// N
	'navigation' => 'navigacioun',
	'nom' => 'Noum',
	'nouveautes' => 'Li nouvità',
	'nouveautes_web' => 'Nouvità soubre lou web',
	'nouveaux_articles' => 'Article nòu',
	'nouvelles_breves' => 'Brèva nouvèli',

	// P
	'page_precedente' => 'pàgina anterioura',
	'page_suivante' => 'pàgina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Poudès participà a la vida d’estou sit e proupausà lu vouòstre article en v’inscrivant aquì souta. Receverès un e-mail que v’endiquerà lu vouòstre code d’achès a l’espaci privat dóu sit.',
	'plan_site' => 'Plan dóu sit',
	'popularite' => 'Poupularità',
	'poster_message' => 'Poustà un message',
	'proposer_site' => 'Poudès prepauà un sit a ajustà en aquela rùbrica :',

	// R
	'repondre_article' => 'Respouòndre en aquel article',
	'repondre_breve' => 'Respouòndre en aquela brèva',
	'resultats_recherche' => 'Resultat de la recerca',
	'retour_debut_forums' => 'Retour au principi dei fòrou',
	'rubrique' => 'Rùbrica',
	'rubriques' => 'Rùbrica',

	// S
	'signatures_petition' => 'Firma',
	'site_realise_avec_spip' => 'Sit realisat embé SPIP',
	'sites_web' => 'Sit web',
	'sous_rubriques' => 'Souta-rùbricas',
	'spam' => 'Spam',
	'suite' => 'suita',
	'sur_web' => 'Soubre lou web',
	'syndiquer_rubrique' => 'Sindicà aquela rùbrica',
	'syndiquer_site' => 'Sindicà tout lou sit',

	// T
	'texte_lettre_information' => 'Vequì la letra d’informacioun dóu sit',
	'texte_lettre_information_2' => 'Aquela letra fa lou chensimen dei nouvità publicadi despì',

	// V
	'ver_imprimer' => 'Versioun d’estampà',
	'voir_en_ligne' => 'Veire en ligna',
	'voir_squelette' => 'Veire l’esquelètrou d’aquela pàgina'
);

?>

==> spip_3.1.3.orig.tar.xz: spip/ecrire/lang/public_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuèlh',
	'article' => 'Article',
	'articles' => 'Article',
	'articles_auteur' => 'Article d’aquel autour',
	'articles_populaires' => 'Lu article lu mai poupulari',
	'articles_rubrique' => 'Article d’aquela rùbrica',
	'aucun_article' => 'Lì es mìnga d’article en aquela adressa',
	'aucun_auteur' => 'Lì es mìnga d’autour en aquela adressa',
	'aucun_site' => 'Lì es mìnga de sit en aquela adressa',
	'aucune_breve' => 'Lì es mìnga de brèva en aquela adressa',
	'aucune_rubrique' => 'Lì es mìnga de rùbrica en aquela adressa',
	'auteur' => 'Autour',
	'autres' => 'Autre',
	'autres_breves' => 'Autri brèva',
	'autres_groupes_mots_clefs' => 'Autre groupe de mot clau',
	'autres_sites' => 'Autre sit',

	// B
	'bonjour' => 'Bouònjou',

	// C
	'commenter_site' => 'Coumentà aqueu sit',
	'contact' => 'Countat',
	'copie_document_impossible' => 'Empoussible de coupià lou doucumen',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrié ajust',
	'dernieres_breves' => 'Darrieri brèva',
	'derniers_articles' => 'Darrié article',
	'derniers_commentaires' => 'Darrié coumentari',
	'derniers_messages_forum' => 'Darrié message publicat en lu fòrou',

	// E
	'edition_mode_texte' => 'Edicioun en mòdou tèst de',
	'en_reponse' => 'En respouòsta a :',
	'en_resume' => 'En coumpendiat',
	'envoyer_message' => 'Mandà un message',
	'espace_prive' => 'Espaci privat',

	// F
	'formats_acceptes' => 'Fourmat achetat : @formats@.',

	// H
	'hierarchie_site' => 'Ierarquìa dóu sit',

	// J
	'jours' => 'jou',

	// L
	'lien_connecter' => 'Si counetà',

	// M
	'meme_auteur' => 'Dóu meme autour',
	'meme_rubrique' => 'En la mema rùbrica',
	'memes_auteurs' => 'Dei meme autour',
	'message' => 'Message',
	'messages_forum' => 'Message',
	'messages_recents' => 'Lu message de fòrou lu mai rechent',
	'mots_clef' => 'Mot clau',
	'mots_clefs' => 'Mot clau',
	'mots_clefs_meme_groupe' => 'Mot clau en lou meme groupe',

	// N
	'navigation' => 'navigacioun',
	'nom' => 'Noum',
	'nouveautes' => 'Li nouvità',
	'nouveautes_web' => 'Nouvità soubre lou web',
	'nouveaux_articles' => 'Nouvèl article',
	'nouvelles_breves' => 'Brèva nouvèli',

	// P
	'page_precedente' => 'pàgina anterioura',
	'page_suivante' => 'pàgina seguenta',
	'par_auteur' => 'da',
	'participer_site' => 'Poudès participà a la vida d’estou sit e proupausà lu vouòstre article en v’inscrivant aquì souta. Receverès un e-mail que v’endiquerà lu vouòstre code d’achès a l’espaci privat dóu sit.',
	'plan_site' => 'Plan dóu sit',
	'popularite' => 'Poupularità',
	'poster_message' => 'Poustà un message',
	'proposer_site' => 'Poudès prepauà un sit a ajustà en aquela rùbrica :',

	// R
	'repondre_article' => 'Respouòndre en aquel article',
	'repondre_breve' => 'Respouòndre en aquela brèva',
	'resultats_recherche' => 'Resultat de la recerca',
	'retour_debut_forums' => 'Retour au principi dai fòrou',
	'rubrique' => 'Rùbrica',
	'rubriques' => 'Rùbrica',

	// S
	'signatures_petition' => 'Firma',
	'site_realise_avec_spip' => 'Sit realisat embé SPIP',
	'sites_web' => 'Sit web',
	'sous_rubriques' => 'Souta-rùbricas',
	'spam' => 'Spam',
	'suite' => 'suita',
	'sur_web' => 'Soubre lou web',
	'syndiquer_rubrique' => 'Sindicà aquela rùbrica',
	'syndiquer_site' => 'Sindicà tout lou sit',

	// T
	'texte_lettre_information' => 'Vequì la letra d’informacioun dóu sit',
	'texte_lettre_information_2' => 'Aquela letra fa lou chensimen dei nouvità publicadi despì',

	// V
	'ver_imprimer' => 'Versioun d’estampà',
	'voir_en_ligne' => 'Veire en ligna',
	'voir_squelette' => 'Veire l’esquelètrou d’aquela pàgina'
);

?>
